@@ -18,7 +18,7 @@
 #include "../pen_gesture/login_screen.h"
 
 
-//#define SKIP_LOGIN 1
+#define SKIP_LOGIN 1
 static void finalize_welcome(ClutterTimeline* timeline, gpointer none)  {
 	ClutterActor* actor;
 
