@@ -176,8 +176,8 @@ static void setSoundKitNum(int s){
 	isJammerPlaying = TRUE;
 }
 
-static int sort1(const void *x1, const void *y1) {
-    return (*(int*)x1 - *(int*)y1);
+static int sort1(const void* x1_parameter, const void* y1_parameter) {
+    return (*(int*)x1_parameter - *(int*)y1_parameter);
 }
 
 static int distance(int pointA[3],int pointB[3] ){
@@ -555,16 +555,16 @@ static int motion_detect(int e, int firsttime){
     //lets find the lowest values
     int kk = 0;
     int i1 = 0;
-    int j1 = 0;
+    int j1_ = 0;
     int k1 = 0;
     while (kk<k_nearest){
-        if ((diffArray[0][i1] <= diffArray[1][j1]) && (diffArray[0][i1] <= diffArray[2][k1])){
+        if ((diffArray[0][i1] <= diffArray[1][j1_]) && (diffArray[0][i1] <= diffArray[2][k1])){
             finalSort[kk] = 0;
             i1++;
-        }else if ((diffArray[1][j1] <= diffArray[0][i1]) && (diffArray[1][j1] < diffArray[2][k1])){
+        }else if ((diffArray[1][j1_] <= diffArray[0][i1]) && (diffArray[1][j1_] < diffArray[2][k1])){
             finalSort[kk] = 1;
-            j1++;
-        }else if ((diffArray[2][k1] < diffArray[0][i1]) && (diffArray[2][k1] < diffArray[1][j1])){
+            j1_++;
+        }else if ((diffArray[2][k1] < diffArray[0][i1]) && (diffArray[2][k1] < diffArray[1][j1_])){
             finalSort[kk] = 2;
             k1++;
         }
