@@ -6,14 +6,14 @@
 #include "community_utilities.h"
 #include "mysongs.h"
 
-static ClutterContainer *imageList = 0;
-static ClutterContainer *widgets = 0;
-ClutterActor *image = 0;
-ClutterActor *recordName = 0;
-ClutterActor *composerName = 0;
-TextField recordNameTextField;
-TextField composerNameTextField;
-const gchar* path;
+static ClutterContainer* imageList = 0;
+static ClutterContainer* widgets = 0;
+static ClutterActor* image = 0;
+static ClutterActor* recordName = 0;
+static ClutterActor* composerName = 0;
+static TextField recordNameTextField;
+static TextField composerNameTextField;
+static const gchar* path;
 
 void start_record_cover_tool(const gchar* filepath){
 		
