@@ -245,11 +245,28 @@ if (load_only_backingtrack){
 					slot_width = json_node_get_int (sub_node);
 				}
 
+				int format_version=2; //Default.
+				//int
+				node = json_object_get_member (object, "format-version");
+				if (node!=NULL && JSON_NODE_TYPE (node) == JSON_NODE_VALUE){
+					format_version = json_node_get_int (node);
+				}
+
+				//slot_width differs from format-version==2
+				if (format_version==2) { //Legacy2
+					if (slot_width==40) slot_width=20; //sandbox-level
+					if (slot_width==80) slot_width=22; //orientation-level
+				}
+
 				track_view = sequencer_track_view_create_editing_track(muted,volume,e_track_type,slot_width,name_of_track);
 
+
 				//Array
 				sub_node = json_object_get_member (sub_object, "samples");
-				load_this_sample_array_to_this_track_view(sub_node,JAMMO_EDITING_TRACK_VIEW(track_view),TRUE); //TRUE=reactive
+				if (format_version==2) //Legacy2
+					load_this_sample_array_to_this_track_view_legacy2(sub_node,JAMMO_EDITING_TRACK_VIEW(track_view),TRUE); //TRUE=reactive
+				else
+					load_this_sample_array_to_this_track_view(sub_node,JAMMO_EDITING_TRACK_VIEW(track_view),TRUE); //TRUE=reactive
 				//Group game
 				if (sequencer_get_group_composition()) {
 					jammo_collaboration_group_composition_new_view(G_OBJECT(sequencer_get_group_composition()), CLUTTER_ACTOR(track_view));
