@@ -811,6 +811,13 @@ static int add_sample_buttons(ClutterActor* looper, samplebutton_tuple table[],
 		jammo_sample_button_set_image_filename(JAMMO_SAMPLE_BUTTON(sample_button),full_image);
 		jammo_sample_button_set_sample_filename(JAMMO_SAMPLE_BUTTON(sample_button), full_sound);
 
+		//name contains _34_ (means 3/4) which means waltz-sample
+		if (new_button.sound!=NULL && g_strrstr(new_button.sound,"_34_")!=NULL) {
+			jammo_sample_button_set_waltz(JAMMO_SAMPLE_BUTTON(sample_button),TRUE);
+			jammo_sample_button_set_text(JAMMO_SAMPLE_BUTTON(sample_button),"3");
+		}
+
+
 		//Logging
 		g_signal_connect (sample_button, "listened", G_CALLBACK (sample_button_listened),NULL);
 
