@@ -56,7 +56,16 @@ TangleButton* last_pressed_volume_button = NULL;
 
 
 
+gboolean sequencer_track_view_start_backingtrack_selection (ClutterActor *track_view, ClutterEvent *event, gpointer user_data) {
+	cem_add_to_log(" Backing_track pressed",J_LOG_USER_ACTION);
+	clutter_actor_show(jammo_get_actor_by_id("backingtrack-selection-view"));
+	clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-view"));
+	backingtrack_selection_set_track_view(CLUTTER_ACTOR(track_view));
 
+	return TRUE;
+}
+
+/* DEPRECATED: track label is not used on clickable button, but label is background for mute+volume*/
 gboolean pressed_sequencer_button_track_label (TangleButton *tanglebutton, gpointer data) {
 	ClutterActor* control_panel_for_this_track = clutter_actor_get_parent(CLUTTER_ACTOR(tanglebutton));
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(control_panel_for_this_track));
@@ -434,9 +443,9 @@ void sequencer_track_view_set_duration(guint64 duration) {
 	guint64 temp=60*tempo_factory;
 	guint64 one_second = 1000000000L;
 	guint64 big = temp * one_second;
-	guint64 duration_of_one_slot = big / jammo_sequencer_get_tempo(sequencer);
-
-	gint n_slots = duration/duration_of_one_slot;
+	guint64 duration_of_one_bar = big / jammo_sequencer_get_tempo(sequencer);
+	guint64 duration_of_one_beat = duration_of_one_bar/4;
+	gint n_slots = duration/duration_of_one_beat;
 	//printf("*number_of_slots (in backing-track / for editing-track): %d\n",n_slots);
 
 
@@ -453,17 +462,16 @@ void sequencer_track_view_set_duration(guint64 duration) {
 	float slot_width;
 	for (tangle_widget_initialize_actor_iterator(TANGLE_WIDGET(container), &actor_iterator); (child = tangle_actor_iterator_get_actor(&actor_iterator)); tangle_actor_iterator_next(&actor_iterator)) {
 		if (JAMMO_IS_EDITING_TRACK_VIEW(child)) {
-			g_object_set(child,"slot-duration",duration_of_one_slot,NULL);
+			g_object_set(child,"slot-duration",duration_of_one_beat,NULL);
 			g_object_set(child,"n-slots",number_of_slots,NULL);
 			g_object_get(child,"slot-width",&slot_width,NULL); //float
 		}
 	}
 
-	sequencer_track_view_fix_cursor();
-
 	//tune static variable
 	width_of_slot=slot_width;
 
+	sequencer_track_view_fix_cursor();
 }
 
 
@@ -483,8 +491,8 @@ static void create_control_panel_entry(ClutterActor* track_view_actor, ClutterAc
 	//This is only for log-messages
 	g_object_set(panel_widget, "name",name_of_track_view, NULL);
 
-	//Label
-	tangle_widget_add(TANGLE_WIDGET(panel_widget),label,NULL);
+	//Label as background
+	tangle_widget_set_background_actor(TANGLE_WIDGET(panel_widget),label);
 
 	//Mute
 	ClutterActor* mute_button = tangle_button_new_selectable_with_background_actors (
@@ -552,7 +560,7 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 		duration_of_one_slot = 0;
 	else	
 		duration_of_one_slot = duration_of_the_track / number_of_slots; //these  are static variables
-		
+
 	ClutterActor *label;
 	const gchar* name_of_label_button;
 	JammoTrack* track;
@@ -568,7 +576,7 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 	ClutterActor* track_view_actor = jammo_editing_track_view_new(JAMMO_EDITING_TRACK(track),
           number_of_slots, duration_of_one_slot, slot_width, track_height);
 	clutter_actor_set_reactive(track_view_actor, TRUE);
-	g_object_set(track_view_actor, "line-every-nth-slot", 1, "sample-type", e_type,
+	g_object_set(track_view_actor, "line-every-nth-slot", 4, "sample-type", e_type,
         "name", name_of_track_view,
         "reactive", TRUE,
         NULL);
@@ -621,12 +629,12 @@ ClutterActor* sequencer_track_view_create_editing_track(gboolean muted, gfloat v
 
 	create_control_panel_entry(track_view_actor, label, name_of_track_view, muted, volume);
 
-	//tune cursor
-	sequencer_track_view_fix_cursor();
-
 	//tune static variable
 	width_of_slot=slot_width;
 
+	//tune cursor
+	sequencer_track_view_fix_cursor();
+
 	return track_view_actor;
 }
 
@@ -684,11 +692,15 @@ ClutterActor* sequencer_track_view_create_backing_track(gboolean muted, gfloat v
 
 	label = tangle_button_new_with_background_actor(tangle_texture_new(name_of_label_button));
 	g_free(name_of_label_button);
-	g_signal_connect(label, "clicked", G_CALLBACK(pressed_sequencer_button_track_label), track_view_actor);
-
 
 	create_control_panel_entry(track_view_actor, label, name_of_track_view, muted, volume);
 
+	//Long click on backingtrack => backingtrack_selection
+	clutter_actor_set_reactive(track_view_actor,TRUE);
+	ClutterAction* action = tangle_hold_action_new();
+	g_signal_connect_swapped(action, "held", G_CALLBACK(sequencer_track_view_start_backingtrack_selection), track_view_actor);
+	clutter_actor_add_action(track_view_actor, action);
+
 	return track_view_actor;
 }
 
