@@ -120,15 +120,16 @@ static void on_sample_duration_notify(GObject* object, GParamSpec* pspec, gpoint
 
 // get_duration_of_slot returns the current duration of one slot. tempo is asked from jammo-editing-track
 static guint64 get_duration_of_slot(JammoEditingTrack * editing_track) {
-	guint64 duration_of_slot=0;
+	guint64 duration_of_beat=0;
 	gint beats_per_bar = jammo_editing_track_get_time_signature_beats(editing_track);
 	//We want operate whole time with guint64.
 	guint64 temp=60*beats_per_bar;
 	guint64 one_second = 1000000000L;
 	guint64 big = temp * one_second * jammo_editing_track_get_time_signature_note_value(editing_track);
 	// 4.0 comes from bpm (x quarter notes in a minute)
-	duration_of_slot = ((gdouble)big / jammo_editing_track_get_tempo(editing_track) / 4.0);
-	return duration_of_slot;
+	// 4 because there are four beat per bar
+	duration_of_beat = ((gdouble)big / jammo_editing_track_get_tempo(editing_track) / 4.0 /4);
+	return duration_of_beat;
 }
 
 /* Note! This function does not check if the given sample will be overlapping some other sample. */
@@ -751,6 +752,21 @@ static gboolean is_droppable(JammoEditingTrackView* track_view, TangleDragAction
 			    !check_if_overlapping(track_view, meta_actor, *slot_return)) {
 				droppable = TRUE;
 			}
+
+			//slot_return is guint, it is possible it is 'negative', which then means 'something big'
+			if (*slot_return > 100000) {
+				droppable = FALSE;
+			}
+
+			//Waltz-samples can be dropped to any beat, non-waltz only to first beat of bar
+			else if (!jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(meta_actor)) && (*slot_return%4!=0)){
+				if (*slot_return%4 == 1)
+					*slot_return-=1;
+				else if (*slot_return%4 == 2)
+					*slot_return+=2;
+				else if (*slot_return%4 == 3)
+					*slot_return+=1;
+			}
 		}
 	}
 	
@@ -838,6 +854,16 @@ static void on_dropped(TangleDropAction* drop_action, TangleDragAction* drag_act
 		center_x -= (n_slots - 1) * track_view->priv->real_slot_width / 2;
 		slot = center_x / track_view->priv->real_slot_width;
 
+		//Waltz-samples can be dropped to any beat, non-waltz only to first beat of bar
+		if (!jammo_sample_button_is_waltz(JAMMO_SAMPLE_BUTTON(sample_button))) {
+			if (slot%4 == 1)
+				slot-=1;
+			else if (slot%4 == 2)
+				slot+=2;
+			else if (slot%4 == 3)
+				slot+=1;
+		}
+
 		jammo_editing_track_add_sample(track_view->priv->track, jammo_sample_button_get_sample(JAMMO_SAMPLE_BUTTON(copy_of_sample_button)), slot * get_duration_of_slot(track_view->priv->track));
 
 		/* tangle_draggable_actor_set_floating_mode_dragged(TANGLE_DRAGGABLE_ACTOR(copy_of_sample_button), TANGLE_FLOATING_MODE_COLLAPSE); */
