@@ -903,7 +903,7 @@ static void on_actor_removed(TangleWidget* widget, ClutterActor* actor, gpointer
 void jammo_miditrack_view_remove_all(JammoMiditrackView* miditrack_view) {
 	g_return_if_fail(JAMMO_IS_MIDITRACK_VIEW(miditrack_view));
 
-	printf("jammo_miditrack_view_remove_all\n");
+	//printf("jammo_miditrack_view_remove_all\n");
 	TangleWidget* widget = TANGLE_WIDGET(miditrack_view);
 	GList* children = clutter_container_get_children(CLUTTER_CONTAINER(widget));
 	if (children) {
