@@ -51,8 +51,6 @@ guint jammo_sample_get_tempo(JammoSample* sample);
 void jammo_sample_set_tempo(JammoSample* sample, guint tempo);
 const gchar* jammo_sample_get_pitch(JammoSample* sample);
 void jammo_sample_set_pitch(JammoSample* sample, const gchar* pitch);
-guint64 jammo_sample_get_start(JammoSample* sample);
-void jammo_sample_set_start(JammoSample* sample, guint64 start);
 
 void jammo_sample_play(JammoSample* sample);
 void jammo_sample_stop(JammoSample* sample);
